/* 
This program (formats_for_household_file.sas) creates the formats
catalog for household_file.sas7bdat.

Instructions for Windows users:

1. Create a folder for your files, e.g. c:\sasfiles
2. Place household_file.sas7bdat and formats_for_household_file.sas
   in the folder
3. Edit the libname statement in formats_for_household_file.sas so that
   it refers to the folder, e.g.: libname library 'c:\sasfiles'
4. Open and run formats_for_household_file.sas.  This will create
   the formats catalog, "formats.sas7bcat" in that folder.
5. You may now use household_file.sas7bdat any way you
   like, for example the following program will create a frequency listing:

   libname library 'c:\sasfiles';
   proc freq data=library.household_file; 
      tables _all_;
   run;

   Note that by using the name "library" for your libname when inputting the 
   data, SAS will automatically look in that same location for the formats
   catalog.  Otherwise, you would need to use a "fmtsearch" option to tell
   SAS where to look for the formats catalog.
*/

libname library '';

proc format library=library;

   value V00001F 
      1 = "01-YES"
      2 = "02-NO"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00002F 
      1 = "01-YES"
      2 = "02-NO"
      99 = "99-REFUSED"
   ;
   value V00003F 
      1 = "01-YES - TRANSFERRING"
      2 = "02-UNAVAILABLE"
      99 = "99-REFUSAL"
   ;
   value V00004F 
      1 = "01-ANYBOAT"
   ;
   value V00005F 
      1 = "1-LONGEST BOAT"
      2 = "2-SECOND LONGEST BOAT"
      3 = "3-THIRD LONGEST BOAT"
      4 = "4-FOURTH LONGEST BOAT"
      5 = "5-FIFTH LONGEST BOAT"
      6 = "6-SIXTH LONGEST BOAT"
      7 = "7-SEVENTH LONGEST BOAT"
      8 = "8-EIGHTH LONGEST BOAT"
      9 = "9-NINTH LONGEST BOAT"
   ;
   value V00006F 
      1 = "01-YES"
      2 = "02-NO"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00007F 
      1 = "01-YES"
      2 = "02-NO"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00008F 
      1 = "01-YES TRANSFERRING TO ADULT"
      2 = "02-NOT AVAILABLE"
      99 = "99-REFUSED"
   ;
   value V00009F 
      1 = "01-YES"
      2 = "02-NO"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00010F 
      1 = "01-YES"
      2 = "02-NO"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00011F 
      1 = "01-YES"
      2 = "02-NO"
      97 = "97-DK"
      99 = "99-REFUSED"
   ;
   value V00012F 
      1 = "01-YES"
      2 = "02-NO"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00013F 
      1 = "01-YES"
      2 = "02-NO"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00014F 
      1 = "01-YES"
      2 = "02-NO"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00015F 
      1 = "01-A POWERBOAT,"
      2 = "02-A SAILBOAT"
      3 = "03-A PERSONAL WATERCRAFT SUCH AS A JET SKI"
      4 = "04-CANOE"
      5 = "05-KAYAK"
      6 = "06-SOMETHING ELSE"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00016F 
      1 = "01-A POWERBOAT,"
      2 = "02-A SAILBOAT"
      3 = "03-A PERSONAL WATERCRAFT SUCH AS A JET SKI"
      4 = "04-CANOE"
      5 = "05-KAYAK"
      6 = "06-SOMETHING ELSE"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00017F 
      1 = "01-A POWERBOAT,"
      2 = "02-A SAILBOAT"
      3 = "03-A PERSONAL WATERCRAFT SUCH AS A JET SKI"
      4 = "04-CANOE"
      5 = "05-KAYAK"
      6 = "06-SOMETHING ELSE"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00018F 
      1 = "01-A POWERBOAT,"
      2 = "02-A SAILBOAT"
      3 = "03-A PERSONAL WATERCRAFT SUCH AS A JET SKI"
      4 = "04-CANOE"
      5 = "05-KAYAK"
      6 = "06-SOMETHING ELSE"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00019F 
      1 = "01-A POWERBOAT,"
      2 = "02-A SAILBOAT"
      3 = "03-A PERSONAL WATERCRAFT SUCH AS A JET SKI"
      4 = "04-CANOE"
      5 = "05-KAYAK"
      6 = "06-SOMETHING ELSE"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00020F 
      1 = "01-A POWERBOAT,"
      2 = "02-A SAILBOAT"
      3 = "03-A PERSONAL WATERCRAFT SUCH AS A JET SKI"
      4 = "04-CANOE"
      5 = "05-KAYAK"
      6 = "06-SOMETHING ELSE"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00021F 
      1 = "01-A POWERBOAT,"
      2 = "02-A SAILBOAT"
      3 = "03-A PERSONAL WATERCRAFT SUCH AS A JET SKI"
      4 = "04-CANOE"
      5 = "05-KAYAK"
      6 = "06-SOMETHING ELSE"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00022F 
      1 = "01-A POWERBOAT,"
      2 = "02-A SAILBOAT"
      3 = "03-A PERSONAL WATERCRAFT SUCH AS A JET SKI"
      4 = "04-CANOE"
      5 = "05-KAYAK"
      6 = "06-SOMETHING ELSE"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00023F 
      1 = "01-A POWERBOAT,"
      2 = "02-A SAILBOAT"
      3 = "03-A PERSONAL WATERCRAFT SUCH AS A JET SKI"
      4 = "04-CANOE"
      5 = "05-KAYAK"
      6 = "06-SOMETHING ELSE"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00024F 
      1 = "01-YES"
      2 = "02-NO"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00025F 
      1 = "01-YES"
      2 = "02-NO"
      88 = "88-INVALID RESPONSE"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED/MISSING"
   ;
   value V00028F 
      1 = "01-YES"
      2 = "02-NO"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00029F 
      1 = "01-YES"
      2 = "02-NO - WRONG INFORMATION"
   ;
   value V00030F 
      1 = "01-YES"
      2 = "02-NO - WRONG INFORMATION"
   ;
   value V00037F 
      1 = "01-YES"
      2 = "02-NO"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00038F 
      1 = "01-YES"
      2 = "02-NO"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00039F 
      1 = "01-YES"
      2 = "02-NO"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00040F 
      1 = "01-YES"
      2 = "02-NO"
      88 = "88-INVALID RESPONSE"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED/MISSING"
   ;
   value V00041F 
      1 = "01-YES"
      2 = "02-NO"
      88 = "88-INVALID RESPONSE"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED/MISSING"
   ;
   value V00042F 
      1 = "01-YES"
      2 = "02-NO"
      88 = "88-INVALID RESPONSE"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED/MISSING"
   ;
   value V00043F 
      1 = "01-YES"
      2 = "02-NO"
      88 = "88-INVALID RESPONSE"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED/MISSING"
   ;
   value V00044F 
      1 = "01-YES"
      2 = "02-NO"
      88 = "88-INVALID RESPONSE"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED/MISSING"
   ;
   value V00045F 
      1 = "01-YES"
      2 = "02-NO"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00046F 
      1 = "01-YES"
      2 = "02-NO"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00047F 
      1 = "01-YES"
      2 = "02-NO"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00048F 
      1 = "01-YES"
      2 = "02-NO"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00050F 
      1 = "01-ALL OR ALMOST ALL CALLS RECEIVED ON CELL PHONES"
      2 = "02-SOME RECEIVED ON CELL PHONES AND SOME ON REGULAR PHONES"
      3 = "03-VERY FEW OR NONE ON CELL PHONES"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00051F 
      1 = "01-ALL OR ALMOST ALL CALLS RECEIVED ON CELL PHONES"
      2 = "02-SOME RECEIVED ON CELL PHONES AND SOME ON REGULAR PHONES"
      3 = "03-VERY FEW OR NONE ON CELL PHONES"
      88 = "88-INVALID RESPONSE"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED/MISSING"
   ;
   value DKRF2F 
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value PREF 
      1 = "01-ANSWER PROVIDED"
      99 = "99-MISSING"
   ;
   value HAPPF 
      1 = "01-I NEVER OWNED THAT BOAT"
      2 = "02-I SOLD OR GAVE AWAY THE BOAT"
      3 = "03-SOMETHING ELSE (PLEASE EXPLAIN)"
      88 = "88-INVALID RESPONSE"
      99 = "99-MISSING"
   ;
   value V00052F 
      1 = "01-YES"
      2 = "02-NO"
      88 = "88-INVALID RESPONSE"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED/MISSING"
   ;
   value V00054F 
      1 = "01-ALUMINUM"
      2 = "02-STEEL"
      3 = "03-CARBON FIBER"
      4 = "04-FIBERGLASS"
      5 = "05-RIGID HULL INFLATABLE"
      6 = "06-RUBBER"
      7 = "07-VINYL"
      8 = "08-CANVAS"
      9 = "09-WOOD"
      10 = "10-ANOTHER MATERIAL"
      11 = "11-PLASTIC (BACK-CODED)"
      88 = "88-INVALID RESPONSE"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED/MISSING"
   ;
   value V00055F 
      1 = "01-CONTINUE"
   ;
   value V00056F 
      1 = "01-YES - CONTINUE"
      2 = "02-NO - REFUSAL"
   ;
   value V00057F 
      1 = "01-YES - TRANSFERRING TO ADULT"
      2 = "02-NO OTHER ADULTS IN HOUSEHOLD"
      3 = "03-NOT AVAILABLE"
   ;
   value M00159F 
      1 = "01-GAVE RESPONSE"
      88 = "88-INVALID RESPONSE"
      99 = "99-MISSING"
   ;
   value V00058F 
      1 = "01-YES - CONTINUE"
      2 = "02-NO"
      3 = "03-ANSWERING MACHINE"
   ;
   value V00059F 
      1 = "01-CONTINUE"
   ;
   value V00060F 
      1 = "01-YES"
      2 = "02-NO"
      3 = "03-NOT A SAFE TIME"
      97 = "97-DON'T KNOW / NOT SURE"
      99 = "99-REFUSED"
   ;
   value V00062F 
      1 = "01-YES"
      2 = "02-NO"
      99 = "99-DECLINED INCENTIVE/REFUSED"
   ;
   value V00063F 
      1 = "01-GET IT NOW"
      2 = "02-CALL BACK WHEN CONVENIENT"
   ;
   value V00064F 
      1 = "01-ALLTEL"
      2 = "02-AT& T (CINGULAR)"
      3 = "03-CELLULARONE"
      4 = "04-CENTENNIAL"
      5 = "05-LEAP (CRICKET)"
      6 = "06-METROPCS"
      7 = "07-NEXTEL"
      8 = "08-QUEST"
      9 = "09-SPRINT"
      10 = "10-SUNCOM"
      11 = "11-T-MOBILE"
      12 = "12-UNICEL (RURAL CELLULAR)"
      13 = "13-US CELLULAR"
      14 = "14-VERIZON"
      15 = "15-NONE OF THESE"
      97 = "97-DON'T KNOW / NOT SURE"
      99 = "99-REFUSED"
   ;
   value V00065F 
      1 = "01-GET IT NOW"
      2 = "02-CALL BACK WHEN CONVENIENT"
   ;
   value V00066F 
      1 = "01-YES"
      2 = "02-NO"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value LNDF 
      1 = "01-GAVE RESPONSE"
      88 = "88-INVALID RESPONSE"
      99 = "99-MISSING"
   ;
   value V00068F 
      1 = "01-YES"
      2 = "02-NO"
      88 = "88-INVALID RESPONSE"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED/MISSING"
   ;
   value LN3F 
      888 = "888-INVALID RESPONSE"
      997 = "997-DON'T KNOW"
      999 = "999-REFUSED/MISSING"
   ;
   value MODEF 
      1 = "1-PHONE"
      2 = "2-MAIL"
   ;
   value DKRF4F 
      8888 = "8888-INVALID RESPONSE"
      9997 = "9997-DON'T KNOW"
      9999 = "9999-REFUSED/MISSING"
   ;
   value V00070F 
      1 = "01-YES"
      2 = "02-NO"
      88 = "88-INVALID RESPONSE"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED/MISSING"
   ;
   value V00071F 
      1 = "01-YES"
      2 = "02-NO"
      88 = "88-INVALID RESPONSE"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED/MISSING"
   ;
   value V00072F 
      1 = "01-YES"
      2 = "02-NO"
      88 = "88-INVALID RESPONSE"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED/MISSING"
   ;
   value V00073F 
      1 = "01-YES"
      2 = "02-NO"
      88 = "88-INVALID RESPONSE"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED/MISSING"
   ;
   value V00074F 
      1 = "01-YES"
      2 = "02-NO"
      88 = "88-INVALID RESPONSE"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED/MISSING"
   ;
   value V00075F 
      1 = "01-YES"
      2 = "02-NO"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00076F 
      1 = "01-YES"
      2 = "02-NO"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00077F 
      1 = "01-YES"
      2 = "02-NO"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00078F 
      1 = "01-YES"
      2 = "02-NO"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00079F 
      1 = "01-DIESEL"
      2 = "02-ELECTRIC"
      3 = "03-GASOLINE"
      4 = "04-ANOTHER TYPE OF FUEL"
      5 = "05-GAS/OIL MIXTURE (BACK-CODED)"
      88 = "88-INVALID RESPONSE"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED/MISSING"
   ;
   value MOTHPF 
      997 = "997-DON'T KNOW"
      998 = "998-MORE THAN 996 HORSEPOWER"
      999 = "999-REFUSED"
      8888 = "8888-INVALID RESPONSE"
      9999 = "9999-MISSING"
   ;
   value V00080F 
      1 = "01-ONE"
      2 = "02-TWO"
      3 = "03-THREE"
      4 = "04-FOUR"
      5 = "05-FIVE"
      6 = "06-SIX"
      7 = "07-SEVEN"
      8 = "08-EIGHT"
      88 = "88-INVALID RESPONSE"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED/MISSING"
   ;
   value V00081F 
      1 = "01-INBOARD ENGINE"
      2 = "02-OUTBOARD MOTOR"
      3 = "03-INBOARD-OUTBOARD ENGINE"
      88 = "88-INVALID RESPONSE"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED/MISSING"
   ;
   value MSULENGTHCATF 
      1 = "1-LESS THAN 16 FT"
      2 = "2-16 TO 20 FT"
      3 = "3-21 TO 28 FT"
      4 = "4-29 FT OR LONGER"
   ;
   value MSUMODLYRCATF 
      1 = "01-2011 TO 2012"
      2 = "02-2010"
      3 = "03-2009"
      4 = "04-2007 TO 2008"
      5 = "05-2005 TO 2006"
      6 = "06-2002 TO 2004"
      7 = "07-1997 TO 2001"
      8 = "08-PRIOR TO 1997"
      9 = "09-REFUSED/INVALID/MISSING"
   ;
   value MSUMOTHPCATF 
      996 = "996-HORSEPOWER CODED AS BETWEEN 1000 AND 2500"
      998 = "998-HORSEPOWER RECODED AS BEING BETWEEN 1000 AND 2500"
   ;
   value DKRF3F 
      997 = "997-DON'T KNOW"
      999 = "999-REFUSED"
   ;
   value MSUTYPESIZEXF 
      1 = "01-POWERBOAT LESS THAN 16 FT"
      2 = "02-POWERBOAT 16 TO 20 FT"
      3 = "03-POWERBOAT 21 TO 28 FT"
      4 = "04-POWERBOAT 29 FT OR LONGER"
      5 = "05-SAILBOAT LESS THAN 16 FT"
      6 = "06-SAILBOAT 16 TO 20 FT"
      7 = "07-SAILBOAT 21 TO 28 FT"
      8 = "08-SAILBOAT 29 FT OR LONGER"
      9 = "09-PWC"
      10 = "10-CANOE & KAYAK"
   ;
   value V00005_2F 
      1 = "1-LONGEST BOAT"
      2 = "2-SECOND LONGEST BOAT"
      3 = "3-THIRD LONGEST BOAT"
      4 = "4-FOURTH LONGEST BOAT"
      5 = "5-FIFTH LONGEST BOAT"
      6 = "6-SIXTH LONGEST BOAT"
      7 = "7-SEVENTH LONGEST BOAT"
      8 = "8-EIGHTH LONGEST BOAT"
      9 = "9-NINTH LONGEST BOAT"
   ;
   value V00082F 
      1 = "01-SUCCESSFUL TRANSFER"
      2 = "02-REFUSE TO TRANSFER"
      3 = "03-CALLBACK TO COMPLETE"
   ;
   value V00083F 
      1 = "01-NEW"
      2 = "02-USED"
      88 = "88-INVALID RESPONSE"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED/MISSING"
   ;
   value V00085F 
      1 = "01-YES - CORRECT"
      2 = "02-NO"
   ;
   value V00090F 
      1 = "01-YES"
      2 = "02-NO"
      88 = "88-INVALID RESPONSE"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED/MISSING"
   ;
   value V00091F 
      1 = "01-YES"
      2 = "02-NO"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00092F 
      1 = "01-YES"
      2 = "02-NO"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value M00001F 
      1 = "01-YES"
      2 = "02-NO"
      88 = "88-INVALID RESPONSE"
      99 = "99-MISSING"
   ;
   value V00094F 
      1 = "01-VERY EXPERIENCED"
      2 = "02-SOMEWHAT EXPERIENCED"
      3 = "03-SOMEWHAT INEXPERIENCED"
      4 = "04-VERY INEXPERIENCED"
      88 = "88-INVALID RESPONSE"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED/MISSING"
   ;
   value V00095F 
      1 = "01-YES"
      2 = "02-NO"
      88 = "88-INVALID RESPONSE"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED/MISSING"
   ;
   value PAGEA 
      95 = "95-AGE 95 OR OLDER"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00144F 
      1 = "01-0 TO 5"
      2 = "02-6 TO 10"
      3 = "03-11 TO 15"
      4 = "04-16 TO 24"
      5 = "05-25 TO 34"
      6 = "06-35 TO 44"
      7 = "07-45 TO 54"
      8 = "08-55 TO 64"
      9 = "09-65 AND OVER"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00145F 
      1 = "01-YES"
      2 = "02-NO"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00146F 
      1 = "01-YES"
      2 = "02-NO"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00147F 
      1 = "01-YES"
      2 = "02-NO"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00148F 
      1 = "01-MALE"
      2 = "02-FEMALE"
      99 = "99-REFUSED"
   ;
   value V00096F 
      1 = "01-16 TO 24"
      2 = "02-25 TO 34"
      3 = "03-35 TO 44"
      4 = "04-45 TO 54"
      5 = "05-55 TO 64"
      6 = "06-65 AND OVER"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00097F 
      1 = "01-YES"
      2 = "02-NO"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00098F 
      1 = "01-YES"
      2 = "02-NO"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00099F 
      1 = "01-YES"
      2 = "02-NO"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00100F 
      1 = "01-YES"
      2 = "02-NO"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00101F 
      1 = "01-YES"
      2 = "02-NO"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00102F 
      1 = "01-YES"
      2 = "02-NO"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00103F 
      1 = "(1) Male"
      2 = "(2) Female"
   ;
   value V00104F 
      1 = "01-0 TO 5"
      2 = "02-6 TO 10"
      3 = "03-11 TO 15"
      4 = "04-16 TO 24"
      5 = "05-25 TO 34"
      6 = "06-35 TO 44"
      7 = "07-45 TO 54"
      8 = "08-55 TO 64"
      9 = "09-65 AND OVER"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00105F 
      1 = "01-YES"
      2 = "02-NO"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00106F 
      1 = "01-YES"
      2 = "02-NO"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00107F 
      1 = "01-YES"
      2 = "02-NO"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00108F 
      1 = "01-MALE"
      2 = "02-FEMALE"
      99 = "99-REFUSED"
   ;
   value V00109F 
      1 = "01-0 TO 5"
      2 = "02-6 TO 10"
      3 = "03-11 TO 15"
      4 = "04-16 TO 24"
      5 = "05-25 TO 34"
      6 = "06-35 TO 44"
      7 = "07-45 TO 54"
      8 = "08-55 TO 64"
      9 = "09-65 AND OVER"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00110F 
      1 = "01-YES"
      2 = "02-NO"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00111F 
      1 = "01-YES"
      2 = "02-NO"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00112F 
      1 = "01-YES"
      2 = "02-NO"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00113F 
      1 = "01-MALE"
      2 = "02-FEMALE"
      99 = "99-REFUSED"
   ;
   value V00114F 
      1 = "01-0 TO 5"
      2 = "02-6 TO 10"
      3 = "03-11 TO 15"
      4 = "04-16 TO 24"
      5 = "05-25 TO 34"
      6 = "06-35 TO 44"
      7 = "07-45 TO 54"
      8 = "08-55 TO 64"
      9 = "09-65 AND OVER"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00115F 
      1 = "01-YES"
      2 = "02-NO"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00116F 
      1 = "01-YES"
      2 = "02-NO"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00117F 
      1 = "01-YES"
      2 = "02-NO"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00118F 
      1 = "01-MALE"
      2 = "02-FEMALE"
      99 = "99-REFUSED"
   ;
   value V00119F 
      1 = "01-0 TO 5"
      2 = "02-6 TO 10"
      3 = "03-11 TO 15"
      4 = "04-16 TO 24"
      5 = "05-25 TO 34"
      6 = "06-35 TO 44"
      7 = "07-45 TO 54"
      8 = "08-55 TO 64"
      9 = "09-65 AND OVER"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00120F 
      1 = "01-YES"
      2 = "02-NO"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00121F 
      1 = "01-YES"
      2 = "02-NO"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00122F 
      1 = "01-YES"
      2 = "02-NO"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00123F 
      1 = "01-MALE"
      2 = "02-FEMALE"
      99 = "99-REFUSED"
   ;
   value V00124F 
      1 = "01-0 TO 5"
      2 = "02-6 TO 10"
      3 = "03-11 TO 15"
      4 = "04-16 TO 24"
      5 = "05-25 TO 34"
      6 = "06-35 TO 44"
      7 = "07-45 TO 54"
      8 = "08-55 TO 64"
      9 = "09-65 AND OVER"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00125F 
      1 = "01-YES"
      2 = "02-NO"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00126F 
      1 = "01-YES"
      2 = "02-NO"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00127F 
      1 = "01-YES"
      2 = "02-NO"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00128F 
      1 = "01-MALE"
      2 = "02-FEMALE"
      99 = "99-REFUSED"
   ;
   value V00129F 
      1 = "01-0 TO 5"
      2 = "02-6 TO 10"
      3 = "03-11 TO 15"
      4 = "04-16 TO 24"
      5 = "05-25 TO 34"
      6 = "06-35 TO 44"
      7 = "07-45 TO 54"
      8 = "08-55 TO 64"
      9 = "09-65 AND OVER"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00130F 
      1 = "01-YES"
      2 = "02-NO"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00131F 
      1 = "01-YES"
      2 = "02-NO"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00132F 
      1 = "01-YES"
      2 = "02-NO"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00133F 
      1 = "01-MALE"
      2 = "02-FEMALE"
      99 = "99-REFUSED"
   ;
   value V00134F 
      1 = "01-0 TO 5"
      2 = "02-6 TO 10"
      3 = "03-11 TO 15"
      4 = "04-16 TO 24"
      5 = "05-25 TO 34"
      6 = "06-35 TO 44"
      7 = "07-45 TO 54"
      8 = "08-55 TO 64"
      9 = "09-65 AND OVER"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00135F 
      1 = "01-YES"
      2 = "02-NO"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00136F 
      1 = "01-YES"
      2 = "02-NO"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00137F 
      1 = "01-YES"
      2 = "02-NO"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00138F 
      1 = "01-MALE"
      2 = "02-FEMALE"
      99 = "99-REFUSED"
   ;
   value V00139F 
      1 = "01-0 TO 5"
      2 = "02-6 TO 10"
      3 = "03-11 TO 15"
      4 = "04-16 TO 24"
      5 = "05-25 TO 34"
      6 = "06-35 TO 44"
      7 = "07-45 TO 54"
      8 = "08-55 TO 64"
      9 = "09-65 AND OVER"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00140F 
      1 = "01-YES"
      2 = "02-NO"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00141F 
      1 = "01-YES"
      2 = "02-NO"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00142F 
      1 = "01-YES"
      2 = "02-NO"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00143F 
      1 = "01-MALE"
      2 = "02-FEMALE"
      99 = "99-REFUSED"
   ;
   value V00149F 
      1 = "01-YES"
      2 = "02-NO"
      88 = "88-INVALID RESPONSE"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED/MISSING"
   ;
   value V00150F 
      1 = "01-YES - GET PANEL INFO"
      2 = "02-NO - REFUSING OPPORTUNITY"
   ;
   value V00152F 
      1 = "01-YES"
      99 = "99-REFUSED"
   ;
   value PCITYF 
      1 = "01-CITY PROVIDED"
      99 = "99-MISSING"
   ;
   value V00153F 
      1 = "01-GAVE RESPONSE/ADDRESS PROVIDED"
      2 = "02-NO"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED/MISSING"
   ;
   value V00154F 
      1 = "01-GAVE RESPONSE"
      2 = "02-NO"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00155F 
      1 = "01-PERSONALIZE WITH NAME/NAME PROVIDED"
      2 = "02-TO RESIDENT IS FINE"
      99 = "99-MISSING"
   ;
   value V00156F 
      1 = "01-THIS NUMBER IS BEST/PHONE PROVIDED"
      2 = "02-DIFFERENT NUMBER"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED/MISSING"
   ;
   value PREFF 
      1 = "01-INTERNET"
      2 = "02-TELEPHONE"
      88 = "88-INVALID RESPONSE"
      99 = "99-MISSING"
   ;
   value V00158F 
      1 = "01-GAVE RESPONSE"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED/MISSING"
   ;
   value V00159F 
      1 = "01-GAVE RESPONSE"
      88 = "88-INVALID RESPONSE"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED/MISSING"
   ;
   value V00160F 
      1 = "01-GAVE RESPONSE"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00161F 
      1 = "01-YES"
      2 = "02-NO"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00162F 
      1 = "01-GAVE RESPONSE"
      88 = "88-INVALID RESPONSE"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED/MISSING"
   ;
   value V00163F 
      1 = "01-GAVE RESPONSE"
      88 = "88-INVALID RESPONSE"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED/MISSING"
   ;
   value V00164F 
      1 = "01-YES"
      2 = "02-NO"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00165F 
      1 = "01-GAVE RESPONSE"
      88 = "88-INVALID RESPONSE"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED/MISSING"
   ;
   value V00166F 
      1 = "01-YES"
      2 = "02-NO"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00167F 
      1 = "01-GAVE RESPONSE"
      88 = "88-INVALID RESPONSE"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED/MISSING"
   ;
   value V00168F 
      1 = "01-GAVE RESPONSE"
      88 = "88-INVALID RESPONSE"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED/MISSING"
   ;
   value V00169F 
      1 = "01-YES"
      2 = "02-NO"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00170F 
      1 = "01-YES"
      2 = "02-NO"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00171F 
      1 = "01-GAVE RESPONSE"
      88 = "88-INVALID RESPONSE"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED/MISSING"
   ;
   value V00172F 
      1 = "01-GAVE RESPONSE"
      88 = "88-INVALID RESPONSE"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED/MISSING"
   ;
   value V00173F 
      1 = "01-YES"
      2 = "02-NO"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00174F 
      1 = "01-YES"
      2 = "02-NO"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00175F 
      1 = "01-YES"
      2 = "02-NO"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00176F 
      1 = "01-YES"
      2 = "02-NO"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00177F 
      1 = "01-GAVE RESPONSE"
      88 = "88-INVALID RESPONSE"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED/MISSING"
   ;
   value V00178F 
      1 = "01-YES"
      2 = "02-NO"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00179F 
      1 = "01-YES"
      2 = "02-NO"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00180F 
      1 = "01-GAVE RESPONSE"
      88 = "88-INVALID RESPONSE"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED/MISSING"
   ;
   value V00181F 
      1 = "01-YES"
      2 = "02-NO"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00182F 
      1 = "01-GAVE RESPONSE"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00183F 
      1 = "01-JANUARY"
      2 = "02-FEBRUARY"
      3 = "03-MARCH"
      4 = "04-APRIL"
      5 = "05-MAY"
      6 = "06-JUNE"
      7 = "07-JULY"
      8 = "08-AUGUST"
      9 = "09-SEPTEMBER"
      10 = "10-OCTOBER"
      11 = "11-NOVEMBER"
      12 = "12-DECEMBER"
   ;
   value V00185F 
      1 = "01-YES"
      2 = "02-NO"
      88 = "88-INVALID RESPONSE"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED/MISSING"
   ;
   value PROCDF 
      1 = "1-PROCEED"
      2 = "2-END"
   ;
   value V00186F 
      1 = "01-HUMAN POWERED WITH OARS, PADDLES, OR PEDALS"
      2 = "02-AIR THRUST"
      3 = "03-PROPELLER"
      4 = "04-SAIL"
      5 = "05-WATER JET"
      88 = "88-INVALID RESPONSE"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED/MISSING"
   ;
   value V00187F 
      1 = "01-GAVE RESPONSE"
      88 = "88-INVALID RESPONSE"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED/MISSING"
   ;
   value V00188F 
      1 = "01-YES"
      2 = "02-NO"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00189F 
      1 = "01-YES"
      2 = "02-NO"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00190F 
      1 = "01-GAVE RESPONSE"
      88 = "88-INVALID RESPONSE"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED/MISSING"
   ;
   value V00191F 
      1 = "01-GAVE RESPONSE"
      88 = "88-INVALID RESPONSE"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED/MISSING"
   ;
   value V00192F 
      1 = "01-GAVE RESPONSE"
      88 = "88-INVALID RESPONSE"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED/MISSING"
   ;
   value RECF 
      1 = "01-BOAT 1"
      2 = "02-BOAT 2"
      3 = "03-BOAT 3"
      4 = "04-BOAT 4"
      5 = "05-I DO NOT OWN ANY OTHER BOATS"
      88 = "88-INVALID RESPONSE"
      99 = "99-MISSING"
   ;
   value V00193F 
      1 = "01-YES ALL CORRECT"
      2 = "02-NEED TO - CORRECT ADDRESS"
      3 = "03-NEED TO - CORRECT APARTMENT NUMBER"
      4 = "04-NEED TO - CORRECT CITY"
      5 = "05-NEED TO - CORRECT STATE"
      6 = "06-NEED TO - CORRECT ZIP CODE"
   ;
   value PSTATE 
      1 = "01-STATE PROVIDED"
      99 = "99-MISSING"
   ;
   value PZIP 
      1 = "01-ZIP PROVIDED"
      99 = "99-MISSING"
   ;
   value V00194F 
      1 = "01-ALL CORRECT"
      2 = "02-CORRECT 1st NAME"
      3 = "03-CORRECT LAST NAME"
   ;
   value V00195F 
      1 = "01-ALABAMA"
      2 = "02-ALASKA"
      4 = "04-ARIZONA"
      5 = "05-ARKANSAS"
      6 = "06-CALIFORNIA"
      8 = "08-COLORADO"
      9 = "09-CONNECTICUT"
      10 = "10-DELAWARE"
      11 = "11-DC"
      12 = "12-FLORIDA"
      13 = "13-GEORGIA"
      15 = "15-HAWAII"
      16 = "16-IDAHO"
      17 = "17-ILLINOIS"
      18 = "18-INDIANA"
      19 = "19-IOWA"
      20 = "20-KANSAS"
      21 = "21-KENTUCKY"
      22 = "22-LOUISIANA"
      23 = "23-MAINE"
      24 = "24-MARYLAND"
      25 = "25-MASSACHUSETTS"
      26 = "26-MICHIGAN"
      27 = "27-MINNESOTA"
      28 = "28-MISSISSIPPI"
      29 = "29-MISSOURI"
      30 = "30-MONTANA"
      31 = "31-NEBRASKA"
      32 = "32-NEVADA"
      33 = "33-NEW HAMPSHIRE"
      34 = "34-NEW JERSEY"
      35 = "35-NEW MEXICO"
      36 = "36-NEW YORK"
      37 = "37-NORTH CAROLINA"
      38 = "38-NORTH DAKOTA"
      39 = "39-OHIO"
      40 = "40-OKLAHOMA"
      41 = "41-OREGON"
      42 = "42-PENNSYLVANIA"
      44 = "44-RHODE ISLAND"
      45 = "45-SOUTH CAROLINA"
      46 = "46-SOUTH DAKOTA"
      47 = "47-TENNESSEE"
      48 = "48-TEXAS"
      49 = "49-UTAH"
      50 = "50-VERMONT"
      51 = "51-VIRGINIA"
      53 = "53-WASHINGTON"
      54 = "54-WEST VIRGINA"
      55 = "55-WISCONSIN"
      56 = "56-WYOMING"
      72 = "72-PUERTO RICO"
      88 = "88-INVALID RESPONSE"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED/MISSING"
   ;
   value V00196F 
      1 = "01-ALABAMA"
      2 = "02-ALASKA"
      4 = "04-ARIZONA"
      5 = "05-ARKANSAS"
      6 = "06-CALIFORNIA"
      8 = "08-COLORADO"
      9 = "09-CONNECTICUT"
      10 = "10-DELAWARE"
      11 = "11-DC"
      12 = "12-FLORIDA"
      13 = "13-GEORGIA"
      15 = "15-HAWAII"
      16 = "16-IDAHO"
      17 = "17-ILLINOIS"
      18 = "18-INDIANA"
      19 = "19-IOWA"
      20 = "20-KANSAS"
      21 = "21-KENTUCKY"
      22 = "22-LOUISIANA"
      23 = "23-MAINE"
      24 = "24-MARYLAND"
      25 = "25-MASSACHUSETTS"
      26 = "26-MICHIGAN"
      27 = "27-MINNESOTA"
      28 = "28-MISSISSIPPI"
      29 = "29-MISSOURI"
      30 = "30-MONTANA"
      31 = "31-NEBRASKA"
      32 = "32-NEVADA"
      33 = "33-NEW HAMPSHIRE"
      34 = "34-NEW JERSEY"
      35 = "35-NEW MEXICO"
      36 = "36-NEW YORK"
      37 = "37-NORTH CAROLINA"
      38 = "38-NORTH DAKOTA"
      39 = "39-OHIO"
      40 = "40-OKLAHOMA"
      41 = "41-OREGON"
      42 = "42-PENNSYLVANIA"
      44 = "44-RHODE ISLAND"
      45 = "45-SOUTH CAROLINA"
      46 = "46-SOUTH DAKOTA"
      47 = "47-TENNESSEE"
      48 = "48-TEXAS"
      49 = "49-UTAH"
      50 = "50-VERMONT"
      51 = "51-VIRGINIA"
      53 = "53-WASHINGTON"
      54 = "54-WEST VIRGINIA"
      55 = "55-WISCONSIN"
      56 = "56-WYOMING"
      72 = "72-PUERTO RICO"
      88 = "88-INVALID RESPONSE"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED/MISSING"
   ;
   value V00197F 
      1 = "01-ALABAMA"
      2 = "02-ALASKA"
      4 = "04-ARIZONA"
      5 = "05-ARKANSAS"
      6 = "06-CALIFORNIA"
      8 = "08-COLORADO"
      9 = "09-CONNECTICUT"
      10 = "10-DELAWARE"
      11 = "11-DC"
      12 = "12-FLORIDA"
      13 = "13-GEORGIA"
      15 = "15-HAWAII"
      16 = "16-IDAHO"
      17 = "17-ILLINOIS"
      18 = "18-INDIANA"
      19 = "19-IOWA"
      20 = "20-KANSAS"
      21 = "21-KENTUCKY"
      22 = "22-LOUISIANA"
      23 = "23-MAINE"
      24 = "24-MARYLAND"
      25 = "25-MASSACHUSETTS"
      26 = "26-MICHIGAN"
      27 = "27-MINNESOTA"
      28 = "28-MISSISSIPPI"
      29 = "29-MISSOURI"
      30 = "30-MONTANA"
      31 = "31-NEBRASKA"
      32 = "32-NEVADA"
      33 = "33-NEW HAMPSHIRE"
      34 = "34-NEW JERSEY"
      35 = "35-NEW MEXICO"
      36 = "36-NEW YORK"
      37 = "37-NORTH CAROLINA"
      38 = "38-NORTH DAKOTA"
      39 = "39-OHIO"
      40 = "40-OKLAHOMA"
      41 = "41-OREGON"
      42 = "42-PENNSYLVANIA"
      44 = "44-RHODE ISLAND"
      45 = "45-SOUTH CAROLINA"
      46 = "46-SOUTH DAKOTA"
      47 = "47-TENNESSEE"
      48 = "48-TEXAS"
      49 = "49-UTAH"
      50 = "50-VERMONT"
      51 = "51-VIRGINIA"
      53 = "53-WASHINGTON"
      54 = "54-WEST VIRGINIA"
      55 = "55-WISCONSIN"
      56 = "56-WYOMING"
      72 = "72-PUERTO RICO"
      88 = "88-INVALID RESPONSE"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED/MISSING"
   ;
   value V00198F 
      1 = "01-ALABAMA"
      2 = "02-ALASKA"
      4 = "04-ARIZONA"
      5 = "05-ARKANSAS"
      6 = "06-CALIFORNIA"
      8 = "08-COLORADO"
      9 = "09-CONNECTICUT"
      10 = "10-DELAWARE"
      11 = "11-DC"
      12 = "12-FLORIDA"
      13 = "13-GEORGIA"
      15 = "15-HAWAII"
      16 = "16-IDAHO"
      17 = "17-ILLINOIS"
      18 = "18-INDIANA"
      19 = "19-IOWA"
      20 = "20-KANSAS"
      21 = "21-KENTUCKY"
      22 = "22-LOUISIANA"
      23 = "23-MAINE"
      24 = "24-MARYLAND"
      25 = "25-MASSACHUSETTS"
      26 = "26-MICHIGAN"
      27 = "27-MINNESOTA"
      28 = "28-MISSISSIPPI"
      29 = "29-MISSOURI"
      30 = "30-MONTANA"
      31 = "31-NEBRASKA"
      32 = "32-NEVADA"
      33 = "33-NEW HAMPSHIRE"
      34 = "34-NEW JERSEY"
      35 = "35-NEW MEXICO"
      36 = "36-NEW YORK"
      37 = "37-NORTH CAROLINA"
      38 = "38-NORTH DAKOTA"
      39 = "39-OHIO"
      40 = "40-OKLAHOMA"
      41 = "41-OREGON"
      42 = "42-PENNSYLVANIA"
      44 = "44-RHODE ISLAND"
      45 = "45-SOUTH CAROLINA"
      46 = "46-SOUTH DAKOTA"
      47 = "47-TENNESSEE"
      48 = "48-TEXAS"
      49 = "49-UTAH"
      50 = "50-VERMONT"
      51 = "51-VIRGINIA"
      53 = "53-WASHINGTON"
      54 = "54-WEST VIRGINIA"
      55 = "55-WISCONSIN"
      56 = "56-WYOMING"
      72 = "72-PUERTO RICO"
      88 = "88-INVALID RESPONSE"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED/MISSING"
   ;
   value V00199F 
      1 = "01-ALABAMA"
      2 = "02-ALASKA"
      4 = "04-ARIZONA"
      5 = "05-ARKANSAS"
      6 = "06-CALIFORNIA"
      8 = "08-COLORADO"
      9 = "09-CONNECTICUT"
      10 = "10-DELAWARE"
      11 = "11-DC"
      12 = "12-FLORIDA"
      13 = "13-GEORGIA"
      15 = "15-HAWAII"
      16 = "16-IDAHO"
      17 = "17-ILLINOIS"
      18 = "18-INDIANA"
      19 = "19-IOWA"
      20 = "20-KANSAS"
      21 = "21-KENTUCKY"
      22 = "22-LOUISIANA"
      23 = "23-MAINE"
      24 = "24-MARYLAND"
      25 = "25-MASSACHUSETTS"
      26 = "26-MICHIGAN"
      27 = "27-MINNESOTA"
      28 = "28-MISSISSIPPI"
      29 = "29-MISSOURI"
      30 = "30-MONTANA"
      31 = "31-NEBRASKA"
      32 = "32-NEVADA"
      33 = "33-NEW HAMPSHIRE"
      34 = "34-NEW JERSEY"
      35 = "35-NEW MEXICO"
      36 = "36-NEW YORK"
      37 = "37-NORTH CAROLINA"
      38 = "38-NORTH DAKOTA"
      39 = "39-OHIO"
      40 = "40-OKLAHOMA"
      41 = "41-OREGON"
      42 = "42-PENNSYLVANIA"
      44 = "44-RHODE ISLAND"
      45 = "45-SOUTH CAROLINA"
      46 = "46-SOUTH DAKOTA"
      47 = "47-TENNESSEE"
      48 = "48-TEXAS"
      49 = "49-UTAH"
      50 = "50-VERMONT"
      51 = "51-VIRGINIA"
      53 = "53-WASHINGTON"
      54 = "54-WEST VIRGINIA"
      55 = "55-WISCONSIN"
      56 = "56-WYOMING"
      72 = "72-PUERTO RICO"
      88 = "88-INVALID RESPONSE"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED/MISSING"
   ;
   value V00200F 
      1 = "01-ALABAMA"
      2 = "02-ALASKA"
      4 = "04-ARIZONA"
      5 = "05-ARKANSAS"
      6 = "06-CALIFORNIA"
      8 = "08-COLORADO"
      9 = "09-CONNECTICUT"
      10 = "10-DELAWARE"
      11 = "11-DC"
      12 = "12-FLORIDA"
      13 = "13-GEORGIA"
      15 = "15-HAWAII"
      16 = "16-IDAHO"
      17 = "17-ILLINOIS"
      18 = "18-INDIANA"
      19 = "19-IOWA"
      20 = "20-KANSAS"
      21 = "21-KENTUCKY"
      22 = "22-LOUISIANA"
      23 = "23-MAINE"
      24 = "24-MARYLAND"
      25 = "25-MASSACHUSETTS"
      26 = "26-MICHIGAN"
      27 = "27-MINNESOTA"
      28 = "28-MISSISSIPPI"
      29 = "29-MISSOURI"
      30 = "30-MONTANA"
      31 = "31-NEBRASKA"
      32 = "32-NEVADA"
      33 = "33-NEW HAMPSHIRE"
      34 = "34-NEW JERSEY"
      35 = "35-NEW MEXICO"
      36 = "36-NEW YORK"
      37 = "37-NORTH CAROLINA"
      38 = "38-NORTH DAKOTA"
      39 = "39-OHIO"
      40 = "40-OKLAHOMA"
      41 = "41-OREGON"
      42 = "42-PENNSYLVANIA"
      44 = "44-RHODE ISLAND"
      45 = "45-SOUTH CAROLINA"
      46 = "46-SOUTH DAKOTA"
      47 = "47-TENNESSEE"
      48 = "48-TEXAS"
      49 = "49-UTAH"
      50 = "50-VERMONT"
      51 = "51-VIRGINIA"
      53 = "53-WASHINGTON"
      54 = "54-WEST VIRGINIA"
      55 = "55-WISCONSIN"
      56 = "56-WYOMING"
      72 = "72-PUERTO RICO"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00201F 
      1 = "01-ALABAMA"
      2 = "02-ALASKA"
      4 = "04-ARIZONA"
      5 = "05-ARKANSAS"
      6 = "06-CALIFORNIA"
      8 = "08-COLORADO"
      9 = "09-CONNECTICUT"
      10 = "10-DELAWARE"
      11 = "11-DC"
      12 = "12-FLORIDA"
      13 = "13-GEORGIA"
      15 = "15-HAWAII"
      16 = "16-IDAHO"
      17 = "17-ILLINOIS"
      18 = "18-INDIANA"
      19 = "19-IOWA"
      20 = "20-KANSAS"
      21 = "21-KENTUCKY"
      22 = "22-LOUISIANA"
      23 = "23-MAINE"
      24 = "24-MARYLAND"
      25 = "25-MASSACHUSETTS"
      26 = "26-MICHIGAN"
      27 = "27-MINNESOTA"
      28 = "28-MISSISSIPPI"
      29 = "29-MISSOURI"
      30 = "30-MONTANA"
      31 = "31-NEBRASKA"
      32 = "32-NEVADA"
      33 = "33-NEW HAMPSHIRE"
      34 = "34-NEW JERSEY"
      35 = "35-NEW MEXICO"
      36 = "36-NEW YORK"
      37 = "37-NORTH CAROLINA"
      38 = "38-NORTH DAKOTA"
      39 = "39-OHIO"
      40 = "40-OKLAHOMA"
      41 = "41-OREGON"
      42 = "42-PENNSYLVANIA"
      44 = "44-RHODE ISLAND"
      45 = "45-SOUTH CAROLINA"
      46 = "46-SOUTH DAKOTA"
      47 = "47-TENNESSEE"
      48 = "48-TEXAS"
      49 = "49-UTAH"
      50 = "50-VERMONT"
      51 = "51-VIRGINIA"
      53 = "53-WASHINGTON"
      54 = "54-WEST VIRGINIA"
      55 = "55-WISCONSIN"
      56 = "56-WYOMING"
      72 = "72-PUERTO RICO"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00202F 
      1 = "01-ALABAMA"
      2 = "02-ALASKA"
      4 = "04-ARIZONA"
      5 = "05-ARKANSAS"
      6 = "06-CALIFORNIA"
      8 = "08-COLORADO"
      9 = "09-CONNECTICUT"
      10 = "10-DELAWARE"
      11 = "11-DC"
      12 = "12-FLORIDA"
      13 = "13-GEORGIA"
      15 = "15-HAWAII"
      16 = "16-IDAHO"
      17 = "17-ILLINOIS"
      18 = "18-INDIANA"
      19 = "19-IOWA"
      20 = "20-KANSAS"
      21 = "21-KENTUCKY"
      22 = "22-LOUISIANA"
      23 = "23-MAINE"
      24 = "24-MARYLAND"
      25 = "25-MASSACHUSETTS"
      26 = "26-MICHIGAN"
      27 = "27-MINNESOTA"
      28 = "28-MISSISSIPPI"
      29 = "29-MISSOURI"
      30 = "30-MONTANA"
      31 = "31-NEBRASKA"
      32 = "32-NEVADA"
      33 = "33-NEW HAMPSHIRE"
      34 = "34-NEW JERSEY"
      35 = "35-NEW MEXICO"
      36 = "36-NEW YORK"
      37 = "37-NORTH CAROLINA"
      38 = "38-NORTH DAKOTA"
      39 = "39-OHIO"
      40 = "40-OKLAHOMA"
      41 = "41-OREGON"
      42 = "42-PENNSYLVANIA"
      44 = "44-RHODE ISLAND"
      45 = "45-SOUTH CAROLINA"
      46 = "46-SOUTH DAKOTA"
      47 = "47-TENNESSEE"
      48 = "48-TEXAS"
      49 = "49-UTAH"
      50 = "50-VERMONT"
      51 = "51-VIRGINIA"
      53 = "53-WASHINGTON"
      54 = "54-WEST VIRGINIA"
      55 = "55-WISCONSIN"
      56 = "56-WYOMING"
      72 = "72-PUERTO RICO"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00203F 
      1 = "01-ALABAMA"
      2 = "02-ALASKA"
      4 = "04-ARIZONA"
      5 = "05-ARKANSAS"
      6 = "06-CALIFORNIA"
      8 = "08-COLORADO"
      9 = "09-CONNECTICUT"
      10 = "10-DELAWARE"
      11 = "11-DC"
      12 = "12-FLORIDA"
      13 = "13-GEORGIA"
      15 = "15-HAWAII"
      16 = "16-IDAHO"
      17 = "17-ILLINOIS"
      18 = "18-INDIANA"
      19 = "19-IOWA"
      20 = "20-KANSAS"
      21 = "21-KENTUCKY"
      22 = "22-LOUISIANA"
      23 = "23-MAINE"
      24 = "24-MARYLAND"
      25 = "25-MASSACHUSETTS"
      26 = "26-MICHIGAN"
      27 = "27-MINNESOTA"
      28 = "28-MISSISSIPPI"
      29 = "29-MISSOURI"
      30 = "30-MONTANA"
      31 = "31-NEBRASKA"
      32 = "32-NEVADA"
      33 = "33-NEW HAMPSHIRE"
      34 = "34-NEW JERSEY"
      35 = "35-NEW MEXICO"
      36 = "36-NEW YORK"
      37 = "37-NORTH CAROLINA"
      38 = "38-NORTH DAKOTA"
      39 = "39-OHIO"
      40 = "40-OKLAHOMA"
      41 = "41-OREGON"
      42 = "42-PENNSYLVANIA"
      44 = "44-RHODE ISLAND"
      45 = "45-SOUTH CAROLINA"
      46 = "46-SOUTH DAKOTA"
      47 = "47-TENNESSEE"
      48 = "48-TEXAS"
      49 = "49-UTAH"
      50 = "50-VERMONT"
      51 = "51-VIRGINIA"
      53 = "53-WASHINGTON"
      54 = "54-WEST VIRGINIA"
      55 = "55-WISCONSIN"
      56 = "56-WYOMING"
      72 = "72-PUERTO RICO"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00204F 
      1 = "01-REGISTERED/YES"
      2 = "02-UNREGISTERED/NO"
      88 = "88-INVALID RESPONSE"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED/MISSING"
   ;
   value V00205F 
      1 = "01-REGISTERED/YES"
      2 = "02-UNREGISTERED/NO"
      88 = "88-INVALID RESPONSE"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED/MISSING"
   ;
   value V00206F 
      1 = "01-REGISTERED/YES"
      2 = "02-UNREGISTERED/NO"
      88 = "88-INVALID RESPONSE"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED/MISSING"
   ;
   value V00207F 
      1 = "01-REGISTERED/YES"
      2 = "02-UNREGISTERED/NO"
      88 = "88-INVALID RESPONSE"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED/MISSING"
   ;
   value V00208F 
      1 = "01-REGISTERED/YES"
      2 = "02-UNREGISTERED/NO"
      88 = "88-INVALID RESPONSE"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED/MISSING"
   ;
   value V00209F 
      1 = "01-REGISTERED"
      2 = "02-UNREGISTERED"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00210F 
      1 = "01-REGISTERED"
      2 = "02-UNREGISTERED"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00211F 
      1 = "01-REGISTERED"
      2 = "02-UNREGISTERED"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00212F 
      1 = "01-REGISTERED"
      2 = "02-UNREGISTERED"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00215F 
      1 = "01-ALABAMA"
      2 = "02-ALASKA"
      4 = "04-ARIZONA"
      5 = "05-ARKANSAS"
      6 = "06-CALIFORNIA"
      8 = "08-COLORADO"
      9 = "09-CONNECTICUT"
      10 = "10-DELAWARE"
      11 = "11-DC"
      12 = "12-FLORIDA"
      13 = "13-GEORGIA"
      15 = "15-HAWAII"
      16 = "16-IDAHO"
      17 = "17-ILLINOIS"
      18 = "18-INDIANA"
      19 = "19-IOWA"
      20 = "20-KANSAS"
      21 = "21-KENTUCKY"
      22 = "22-LOUISIANA"
      23 = "23-MAINE"
      24 = "24-MARYLAND"
      25 = "25-MASSACHUSETTS"
      26 = "26-MICHIGAN"
      27 = "27-MINNESOTA"
      28 = "28-MISSISSIPPI"
      29 = "29-MISSOURI"
      30 = "30-MONTANA"
      31 = "31-NEBRASKA"
      32 = "32-NEVADA"
      33 = "33-NEW HAMPSHIRE"
      34 = "34-NEW JERSEY"
      35 = "35-NEW MEXICO"
      36 = "36-NEW YORK"
      37 = "37-NORTH CAROLINA"
      38 = "38-NORTH DAKOTA"
      39 = "39-OHIO"
      40 = "40-OKLAHOMA"
      41 = "41-OREGON"
      42 = "42-PENNSYLVANIA"
      44 = "44-RHODE ISLAND"
      45 = "45-SOUTH CAROLINA"
      46 = "46-SOUTH DAKOTA"
      47 = "47-TENNESSEE"
      48 = "48-TEXAS"
      49 = "49-UTAH"
      50 = "50-VERMONT"
      51 = "51-VIRGINIA"
      53 = "53-WASHINGTON"
      54 = "54-WEST VIRGINIA"
      55 = "55-WISCONSIN"
      56 = "56-WYOMING"
      72 = "72-PUERTO RICO"
      88 = "88-INVALID RESPONSE"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED/MISSING"
   ;
   value V00216F 
      1 = "01-YES"
      2 = "02-NO"
      97 = "97-DON'T KNOW/NOT SURE"
      99 = "99-REFUSED"
   ;
   value V00286F 
      1 = "01-YES"
      2 = "02-NO"
      88 = "88-INVALID RESPONSE"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED/MISSING"
   ;
   value V00287F 
      1 = "01-PER WEEK"
      2 = "02-PER MONTH"
      3 = "03-PER YEAR"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00288F 
      1 = "01-YES"
      2 = "02-NO"
      88 = "88-INVALID RESPONSE"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED/MISSING"
   ;
   value V00289F 
      1 = "01-YES"
      2 = "02-NO"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value STATF 
      1 = "1-BOAT ONLY"
      2 = "2-BOAT AND PARTICIPANT"
      3 = "3-PARTICIPANT ONLY"
      4 = "4-NON BOAT OWNER (PATCHGRP=2)"
      5 = "5-MAIL: BOAT OWNER"
      6 = "6-MAIL: NON-BOAT OWNER"
      7 = "7-MAIL: DK BOAT"
   ;
   value V00290F 
      1 = "01-ON THE WATER"
      2 = "02-ON LAND"
      88 = "88-INVALID RESPONSE"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED/MISSING"
   ;
   value V00299F 
      1 = "01-A ROWBOAT"
      2 = "02-AN INFLATABLE"
      3 = "03-NEITHER"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00300F 
      1 = "01-A ROWBOAT"
      2 = "02-AN INFLATABLE"
      3 = "03-NEITHER"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00301F 
      1 = "01-A ROWBOAT"
      2 = "02-AN INFLATABLE"
      3 = "03-NEITHER"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00302F 
      1 = "01-A ROWBOAT"
      2 = "02-AN INFLATABLE"
      3 = "03-NEITHER"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00303F 
      1 = "01-A ROWBOAT"
      2 = "02-AN INFLATABLE"
      3 = "03-NEITHER"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00304F 
      1 = "01-A ROWBOAT"
      2 = "02-AN INFLATABLE"
      3 = "03-NEITHER"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00305F 
      1 = "01-A ROWBOAT"
      2 = "02-AN INFLATABLE"
      3 = "03-NEITHER"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00306F 
      1 = "01-A ROWBOAT"
      2 = "02-AN INFLATABLE"
      3 = "03-NEITHER"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00307F 
      1 = "01-A ROWBOAT"
      2 = "02-AN INFLATABLE"
      3 = "03-NEITHER"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00308F 
      1 = "01-A CABIN MOTORBOAT"
      2 = "02-A JET BOAT"
      3 = "03-AN OPEN MOTORBOAT"
      4 = "04-A PONTOON BOAT"
      5 = "05-A HOUSEBOAT"
      6 = "06-AN AIRBOAT"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00309F 
      1 = "01-A CABIN MOTORBOAT"
      2 = "02-A JET BOAT"
      3 = "03-AN OPEN MOTORBOAT"
      4 = "04-A PONTOON BOAT"
      5 = "05-A HOUSEBOAT"
      6 = "06-AN AIRBOAT"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00310F 
      1 = "01-A CABIN MOTORBOAT"
      2 = "02-A JET BOAT"
      3 = "03-AN OPEN MOTORBOAT"
      4 = "04-A PONTOON BOAT"
      5 = "05-A HOUSEBOAT"
      6 = "06-AN AIRBOAT"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00311F 
      1 = "01-A CABIN MOTORBOAT"
      2 = "02-A JET BOAT"
      3 = "03-AN OPEN MOTORBOAT"
      4 = "04-A PONTOON BOAT"
      5 = "05-A HOUSEBOAT"
      6 = "06-AN AIRBOAT"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00312F 
      1 = "01-A CABIN MOTORBOAT"
      2 = "02-A JET BOAT"
      3 = "03-AN OPEN MOTORBOAT"
      4 = "04-A PONTOON BOAT"
      5 = "05-A HOUSEBOAT"
      6 = "06-AN AIRBOAT"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00313F 
      1 = "01-A CABIN MOTORBOAT"
      2 = "02-A JET BOAT"
      3 = "03-AN OPEN MOTORBOAT"
      4 = "04-A PONTOON BOAT"
      5 = "05-A HOUSEBOAT"
      6 = "06-AN AIRBOAT"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00314F 
      1 = "01-A CABIN MOTORBOAT"
      2 = "02-A JET BOAT"
      3 = "03-AN OPEN MOTORBOAT"
      4 = "04-A PONTOON BOAT"
      5 = "05-A HOUSEBOAT"
      6 = "06-AN AIRBOAT"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00315F 
      1 = "01-A CABIN MOTORBOAT"
      2 = "02-A JET BOAT"
      3 = "03-AN OPEN MOTORBOAT"
      4 = "04-A PONTOON BOAT"
      5 = "05-A HOUSEBOAT"
      6 = "06-AN AIRBOAT"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00316F 
      1 = "01-A CABIN MOTORBOAT"
      2 = "02-A JET BOAT"
      3 = "03-AN OPEN MOTORBOAT"
      4 = "04-A PONTOON BOAT"
      5 = "05-A HOUSEBOAT"
      6 = "06-AN AIRBOAT"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00317F 
      1 = "01-AN AUXILIARY MOTOR SAILBOAT"
      2 = "02-A SAIL-ONLY SAILBOAT"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00318F 
      1 = "01-AN AUXILIARY MOTOR SAILBOAT"
      2 = "02-A SAIL-ONLY SAILBOAT"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00319F 
      1 = "01-AN AUXILIARY MOTOR SAILBOAT"
      2 = "02-A SAIL-ONLY SAILBOAT"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00320F 
      1 = "01-AN AUXILIARY MOTOR SAILBOAT"
      2 = "02-A SAIL-ONLY SAILBOAT"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00321F 
      1 = "01-AN AUXILIARY MOTOR SAILBOAT"
      2 = "02-A SAIL-ONLY SAILBOAT"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00322F 
      1 = "01-AN AUXILIARY MOTOR SAILBOAT"
      2 = "02-A SAIL-ONLY SAILBOAT"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00323F 
      1 = "01-AN AUXILIARY MOTOR SAILBOAT"
      2 = "02-A SAIL-ONLY SAILBOAT"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00324F 
      1 = "01-AN AUXILIARY MOTOR SAILBOAT"
      2 = "02-A SAIL-ONLY SAILBOAT"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00325F 
      1 = "01-AN AUXILIARY MOTOR SAILBOAT"
      2 = "02-A SAIL-ONLY SAILBOAT"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00326F 
      1 = "01-YES"
      2 = "02-NO"
      88 = "88-INVALID RESPONSE"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED/MISSING"
   ;
   value V00327F 
      1 = "01-YES"
      2 = "02-NO"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00328F 
      1 = "01-YES"
      2 = "02-NO"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value TYPESF 
      1 = "01-CM CABIN MOTORBOAT"
      2 = "02-OM OPEN MOTORBOAT"
      3 = "03-PB PONTOON BOAT"
      4 = "04-HB HOUSE BOAT"
      5 = "05-JB JET BOAT"
      6 = "06-AB AIR BOAT"
      7 = "07-AS AUXILLARY MOTOR SAIL"
      8 = "08-SO SAIL ONLY"
      9 = "09-JS JETSKI"
      10 = "10-CN CANOE"
      11 = "11-KY KAYAK"
      12 = "12-RB ROWBOAT"
      88 = "88-INVALID RESPONSE"
      99 = "99-MISSING"
   ;
   value V00330F 
      1 = "01-YES"
      2 = "02-NO"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00331F 
      1 = "01-YES"
      2 = "02-NO"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00332F 
      1 = "01-YES"
      2 = "02-NO"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00333F 
      1 = "01-YES"
      2 = "02-NO"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00334F 
      1 = "01-YES"
      2 = "02-NO"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00335F 
      1 = "01-YES"
      2 = "02-NO"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00336F 
      1 = "01-YES"
      2 = "02-NO"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00337F 
      1 = "01-YES"
      2 = "02-NO"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00338F 
      1 = "01-YES"
      2 = "02-NO"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00339F 
      1 = "01-YES"
      2 = "02-NO"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00340F 
      1 = "01-YES"
      2 = "02-NO"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00341F 
      1 = "01-YES"
      2 = "02-NO"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00342F 
      1 = "01-YES"
      2 = "02-NO"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00343F 
      1 = "01-YES"
      2 = "02-NO"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00344F 
      1 = "01-YES"
      2 = "02-NO"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00345F 
      1 = "01-YES"
      2 = "02-NO"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00346F 
      1 = "01-YES"
      2 = "02-NO"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00347F 
      1 = "01-YES"
      2 = "02-NO"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00348F 
      1 = "01-YES"
      2 = "02-NO"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00349F 
      1 = "01-YES"
      2 = "02-NO"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00350F 
      1 = "01-YES"
      2 = "02-NO"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00351F 
      1 = "01-YES"
      2 = "02-NO"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00352F 
      1 = "01-YES"
      2 = "02-NO"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00353F 
      1 = "01-YES"
      2 = "02-NO"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00354F 
      1 = "01-YES"
      2 = "02-NO"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00355F 
      1 = "01-YES"
      2 = "02-NO"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00356F 
      1 = "01-YES"
      2 = "02-NO"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00357F 
      1 = "01-YES"
      2 = "02-NO"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00358F 
      1 = "01-YES"
      2 = "02-NO"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00359F 
      1 = "01-YES"
      2 = "02-NO"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00360F 
      1 = "01-YES"
      2 = "02-NO"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00361F 
      1 = "01-YES"
      2 = "02-NO"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00362F 
      1 = "01-YES"
      2 = "02-NO"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00363F 
      1 = "01-YES"
      2 = "02-NO"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00364F 
      1 = "01-YES"
      2 = "02-NO"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00365F 
      1 = "01-YES"
      2 = "02-NO"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00366F 
      1 = "01-YES"
      2 = "02-NO"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00367F 
      1 = "01-YES"
      2 = "02-NO"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00368F 
      1 = "01-YES"
      2 = "02-NO"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00369F 
      1 = "01-YES"
      2 = "02-NO"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00370F 
      1 = "01-YES"
      2 = "02-NO"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00371F 
      1 = "01-YES"
      2 = "02-NO"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00372F 
      1 = "01-YES"
      2 = "02-NO"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00373F 
      1 = "01-YES"
      2 = "02-NO"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00374F 
      1 = "01-YES"
      2 = "02-NO"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00375F 
      1 = "01-YES"
      2 = "02-NO"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00376F 
      1 = "01-YES"
      2 = "02-NO"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00377F 
      1 = "01-YES"
      2 = "02-NO"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00378F 
      1 = "01-YES"
      2 = "02-NO"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00379F 
      1 = "01-YES"
      2 = "02-NO"
      88 = "88-INVALID RESPONSE"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED/MISSING"
   ;
   value V00380F 
      1 = "01-RECORD NAME"
      99 = "99-REFUSED"
   ;
   value $CALLTF 
      "1" = "01-LANDLINE"
      "2" = "02-CELL"
   ;
   value $EXPF 
      "1" = "01-$5 AT INTRO1"
      "2" = "02-$5 (AT INFOC IF BS1=01) OR (AT PREBT1A IF BS1=2,97,99)"
      "3" = "03-CONTROL GROUP"
   ;
   value $MSUBOATSPECF 
      "01" = "01-CABIN MOTORBOAT"
      "02" = "02-JET BOAT"
      "03" = "03-OPEN MOTORBOAT"
      "04" = "04-PONTOON BOAT"
      "05" = "05-HOUSEBOAT"
      "06" = "06-AIR BOAT"
      "07" = "07-SOME POWER BOAT TYPE"
      "08" = "08-AUXILLARY MOTOR SAIL"
      "09" = "09-SAIL-ONLY SAILBOAT"
      "10" = "10-SOME SAILBOAT TYPE"
      "11" = "11-PWC, JET SKI"
      "12" = "12-CANOE"
      "13" = "13-KAYAK"
      "14" = "14-ROWBOAT"
      "15" = "15-INFLATABLE"
      "16" = "16-SOME OTHER BOAT TYPE"
      "88" = "88-INVALID RESPONSE"
      "97" = "97-DO NOT KNOW"
      "99" = "99-MISSING"
   ;
   value $MSUBOATTYPEF 
      "01" = "01-POWERBOAT"
      "02" = "02-SAILBOAT"
      "03" = "03-PWC"
      "04" = "04-CANOE"
      "05" = "05-KAYAK"
      "06" = "06-SOMETHING ELSE"
      "88" = "88-INVALID RESPONSE"
      "97" = "97-DO NOT KNOW"
      "99" = "99-MISSING"
   ;
   value $MSUSELECTBOATF 
      "01" = "01-FIRST BOAT ( PHONE )"
      "02" = "02-SECOND BOAT ( PHONE & MAIL )"
      "03" = "03-THIRD BOAT ( PHONE & MAIL )"
      "04" = "04-FOURTH BOAT ( PHONE & MAIL )"
      "05" = "05-FIFTH BOAT ( PHONE & MAIL )"
      "06" = "06-SIXTH BOAT ( PHONE )"
      "07" = "07-SEVENTH BOAT ( PHONE )"
      "08" = "08-EIGHTH BOAT ( PHONE )"
      "09" = "09-NINTH BOAT ( PHONE )"
      "F2" = "F2-FAILED LOGIC TEST - SECOND BOAT ( MAIL )"
      "F3" = "F3-FAILED LOGIC TEST - THIRD BOAT ( MAIL )"
      "F4" = "F4-FAILED LOGIC TEST - FOURTH BOAT ( MAIL )"
      "F5" = "F5-FAILED LOGIC TEST - FIFTH BOAT ( MAIL )"
      "FS" = "FS-FAILED LOGIC TEST - SPECIFIED BOAT ( MAIL )"
      "SB" = "SB-SPECIFIED BOAT ( MAIL )"
   ;
   value $MSUVERIFYLENGTHF 
      "-" = "- -LENGTH WAS NOT PROVIDED"
      "L" = "Y-LENGTH PROVIDED WAS TOO LONG"
      "S" = "Y-LENGTH PROVIDED WAS TOO SHORT"
      "Y" = "Y-LENGTH PROVIDED VERIFIED PROPER"
   ;
   value $PATCHF 
      "1" = "01-YES-PATCH QUESTIONS"
      "2" = "02-NO-BOAT SURVEY ONLY"
   ;
   value stateFIPS_fmt 
      1 = "(01) ALABAMA"
      2 = "(02) ALASKA"
      4 = "(04) ARIZONA"
      5 = "(05) ARKANSAS"
      6 = "(06) CALIFORNIA"
      8 = "(08) COLORADO"
      9 = "(09) CONNECTICUT"
      10 = "(10) DELAWARE"
      11 = "(11) DC"
      12 = "(12) FLORIDA"
      13 = "(13) GEORGIA"
      15 = "(15) HAWAII"
      16 = "(16) IDAHO"
      17 = "(17) ILLINOIS"
      18 = "(18) INDIANA"
      19 = "(19) IOWA"
      20 = "(20) KANSAS"
      21 = "(21) KENTUCKY"
      22 = "(22) LOUISIANA"
      23 = "(23) MAINE"
      24 = "(24) MARYLAND"
      25 = "(25) MASSACHUSETTS"
      26 = "(26) MICHIGAN"
      27 = "(27) MINNESOTA"
      28 = "(28) MISSISSIPPI"
      29 = "(29) MISSOURI"
      30 = "(30) MONTANA"
      31 = "(31) NEBRASKA"
      32 = "(32) NEVADA"
      33 = "(33) NEW HAMPSHIRE"
      34 = "(34) NEW JERSEY"
      35 = "(35) NEW MEXICO"
      36 = "(36) NEW YORK"
      37 = "(37) NORTH CAROLINA"
      38 = "(38) NORTH DAKOTA"
      39 = "(39) OHIO"
      40 = "(40) OKLAHOMA"
      41 = "(41) OREGON"
      42 = "(42) PENNSYLVANIA"
      44 = "(44) RHODE ISLAND"
      45 = "(45) SOUTH CAROLINA"
      46 = "(46) SOUTH DAKOTA"
      47 = "(47) TENNESSEE"
      48 = "(48) TEXAS"
      49 = "(49) UTAH"
      50 = "(50) VERMONT"
      51 = "(51) VIRGINIA"
      53 = "(53) WASHINGTON"
      54 = "(54) WEST VIRGINA"
      55 = "(55) WISCONSIN"
      56 = "(56) WYOMING"
      57 = "(57) PUERTO RICO"
   ; 
   value participation_fmt 
      1 = "01-Yes"
      2 = "02-No"
      97 = "97-Don't Know"
      99 = "99-Refused"
   ;
run;
